==> integration-tests-data-index-service-springboot-1.5.0.Final-sources.jar: org/acme/travels/Approvals_2_TaskOutput.java <==
/*
 * Copyright 2019 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.acme.travels;

import java.util.Map;
import java.util.HashMap;
import org.kie.kogito.UserTask;
import org.kie.kogito.UserTaskParam.ParamType;
import org.kie.kogito.UserTaskParam;

@UserTask(taskName = "secondLineApproval", processName = "approvals")
public class Approvals_2_TaskOutput implements org.kie.kogito.MapOutput {

    public Map<String, Object> toMap() {
        Map<String, Object> params = new HashMap();
        params.put("approved", this.approved);
        return params;
    }

    public static Approvals_2_TaskOutput fromMap(Map<String, Object> params) {
        org.acme.travels.Approvals_2_TaskOutput result = new Approvals_2_TaskOutput();
        result.approved = (java.lang.Boolean) params.get("approved");
        return result;
    }

    @UserTaskParam(value = ParamType.OUTPUT)
    private java.lang.Boolean approved;

    public java.lang.Boolean getApproved() {
        return approved;
    }

    public void setApproved(java.lang.Boolean approved) {
        this.approved = approved;
    }
}
// Task output model for user task 'Second Line Approval' in process 'approvals'

==> integration-tests-data-index-service-springboot-1.6.0.Final-sources.jar: org/acme/travels/Approvals_2_TaskOutput.java <==
/*
 * Copyright 2019 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.acme.travels;

import java.util.Map;
import java.util.HashMap;
import org.kie.kogito.UserTask;
import org.kie.kogito.UserTaskParam.ParamType;
import org.kie.kogito.UserTaskParam;

@UserTask(taskName = "secondLineApproval", processName = "approvals")
public class Approvals_2_TaskOutput implements org.kie.kogito.MapOutput {

    public Map<String, Object> toMap() {
        Map<String, Object> params = new HashMap<>();
        params.put("approved", this.approved);
        return params;
    }

    public static Approvals_2_TaskOutput fromMap(Map<String, Object> params) {
        org.acme.travels.Approvals_2_TaskOutput result = new Approvals_2_TaskOutput();
        result.approved = (java.lang.Boolean) params.get("approved");
        return result;
    }

    @UserTaskParam(value = ParamType.OUTPUT)
    private java.lang.Boolean approved;

    public java.lang.Boolean getApproved() {
        return approved;
    }

    public void setApproved(java.lang.Boolean approved) {
        this.approved = approved;
    }
}
// Task output model for user task 'Second Line Approval' in process 'approvals'
